@@ -1,7 +1,7 @@
 /*********************************************************************
  *   Copyright 1993, UCAR/Unidata
  *   See netcdf/COPYRIGHT file for copying and redistribution conditions.
- *   $Header: /upc/share/CVS/netcdf-3/ncdump/vardata.c,v 1.8 2002/01/21 15:20:02 russ Exp $
+ *   $Header: /upc/share/CVS/netcdf-3/ncdump/vardata.c,v 1.9 2004/11/16 21:38:16 russ Exp $
  *********************************************************************/
 
 #include <stdio.h>
@@ -725,7 +725,7 @@ vardata(
     static int initeps = 0;
 
     /* printf format used to print each value */
-    char *fmt = get_fmt(ncid, varid, vp->type);
+    const char *fmt = get_fmt(ncid, varid, vp->type);
 
     if (!initeps) {		/* make sure epsilons get initialized */
 	init_epsilons();
